/*----------------------------------------------------------------------*/
/* Mini-Sentinel package of SAS macros to assist with environment setup */
/*                                                                      */
/*   List of macros included in package                                 */
/*     - MS_CLEAN_PATH  ... cleans & validates path-name                */
/*     - MS_DIREXIST ... checks if directory exists                     */
/*     - MS_LIB ... conditionally assigns libname                       */
/*                                                                      */
/*----------------------------------------------------------------------*/


%macro ms_clean_path(path) ;
  /*****************************************************************************
  *                               MINI-SENTINEL MACRO
  ******************************************************************************
  * NAME:  ms_clean_path
  *
  * PURPOSE:  Clean up path according to MS conventions, then validate it
  *
  * MAJOR STEPS:  
  *  - Replaces back slashes with forward slashes and
  *    checks if path ends with forward slash, appending one if necessary
  *  - Checks if path actually exists and aborts if not
  *
  * KEY DEPENDENCIES/CONSTRAINTS:  calls macro ms_dirExist 
  *
  *------------------------------------------------------------------------------
  * USER-PARAMETERS
  *   path ... name of path, without surrounding quotes (e.g. X:\project-xyz)
  *------------------------------------------------------------------------------
  * CONTACT INFO: 
  *  Mini-Sentinel Coordinating Center
  *  info@mini-sentinel.org
  *
  *------------------------------------------------------------------------------
  * HISTORY:
  *  Create date (mm/dd/yy):  08/27/13
  *  Last modified date (mm/dd/yy): 
  *  Version: 1
  *
  *  CHANGE LOG: 
  *
  *   Version   Date       Comment (reference external documentation if available)
  *   -------   --------   --------------------------------------------------------
  *             mm/dd/yy
  *
  **********************************************************************************/  
 
	%local ln lc d_exist ;
	%let ln = %length(&path) ;
	%if &ln eq 0 %then %do ;
		 %put The parameter path must be non-missing. ;
		 %abort cancel ;
	%end ;
	%else %if &ln > 0 %then %do ;
	   %let path = %sysfunc(translate(&path, %str(/), %str(\))) ;
	   %let lc = %substr(&path, &ln) ;
	   %if "&lc" ne "/" %then %do ;
	   	  %let path = &path./ ;
	   %end ;	   
	   %let d_exist = %ms_dirExist(&path) ;  
     %if &d_exist eq 0 %then %do ;
        %put Path &path does not exist;
        %abort cancel;
     %end ;	   
	%end ;
	&path 	 /* returns value to calling environment, like a function */
%mend ms_clean_path ;


%macro ms_dirExist(dir) ; 
  /*****************************************************************************
  *                               MINI-SENTINEL MACRO
  ******************************************************************************
  * NAME:  ms_dirExist
  *
  * PURPOSE:  Checks if a directory exists, returning 1 if exists, 0 if not, 
  *           aborting if directory is missing.
  *------------------------------------------------------------------------------
  * USER-PARAMETERS
  *   dir ... name of directory, without surrounding quotes (e.g. X:\project-xyz)
  *------------------------------------------------------------------------------
  * CONTACT INFO: 
  *  Mini-Sentinel Coordinating Center
  *  info@mini-sentinel.org
  *
  *------------------------------------------------------------------------------
  * HISTORY:
  *  Create date (mm/dd/yy):  08/27/13
  *  Last modified date (mm/dd/yy): 
  *  Version: 1
  *
  *  CHANGE LOG: 
  *
  *   Version   Date       Comment (reference external documentation if available)
  *   -------   --------   --------------------------------------------------------
  *      1      08/08/13   This is a modified version of a macro created and freely
  *                        shared by Adrien Vallee (see below).  The original macro
  *                        has been modified to clear the filref after use.  It  
  *                        also issues abort cancel if dir is blank.
  *                        
  **********************************************************************************/  	  
	
  /* Original Author: Adrien Vallee */	
  /* Original Source: http://www.sascommunity.org/wiki/Tips:Check_if_a_directory_exists */
  /* Terms of Use: http://www.sascommunity.org/wiki/sasCommunity:Terms_of_Use */

   %if %length(&dir) eq 0 %then %do ;
   	  %put The parameter dir must be non-missing.  ;
   	  %abort cancel ;
   %end ;
   %local rc fileref return ; 
   %let rc = %sysfunc(filename(fileref,&dir)) ; 
   %let return = %sysfunc(fexist(&fileref)) ;  
   &return  /* returns value to calling environment, like a function */
   %let rc = %sysfunc(filename(fileref)) ;  
%mend ms_dirExist;


%macro ms_lib(ref, path, options=) ;
  /*****************************************************************************
  *                               MINI-SENTINEL MACRO
  ******************************************************************************
  * NAME:  ms_lib
  *
  * PURPOSE:  Conditionally assigns a libref with options if the is non-missing,
  *           aborting if non-missing path is invalid
  *
  * KEY DEPENDENCIES/CONSTRAINTS:  calls macro ms_dirExist 
  *
  *------------------------------------------------------------------------------
  * USER-PARAMETERS
  *   ref  ... SAS libref-name (e.g. indata) that SAS uses to point to a path
  *   path ... path-name, without surrounding quotes (e.g. X:\project-xyz)
  *   options ... SAS libname options, with macro-quoting if necessary 
  *               [ e.g. %str(access=readonly) ]
  *------------------------------------------------------------------------------
  * CONTACT INFO: 
  *  Mini-Sentinel Coordinating Center
  *  info@mini-sentinel.org
  *
  *------------------------------------------------------------------------------
  * HISTORY:
  *  Create date (mm/dd/yy):  08/27/13
  *  Last modified date (mm/dd/yy): 
  *  Verizon: 1
  *
  *  CHANGE LOG: 
  *
  *   Version   Date       Comment (reference external documentation if available)
  *   -------   --------   --------------------------------------------------------
  *             mm/dd/yy
  *
  **********************************************************************************/  
  	
  %if %length(&ref) eq 0 %then %do ;
     %put libref is blank ;
	 %abort cancel ;
  %end ;
  %local d_exist ;
  %if %length(&path) eq 0 %then %do ;
     %put MS-NOTE: for libref &ref the path is blank, libname assignment skipped ;
  %end ;
  %else %do ;
     %let d_exist = %ms_dirExist(&path) ;  
     %if &d_exist eq 1 %then %do ;
        libname &ref "&path" &options ;
     %end ;
     %else %do ;
        %put Path &path does not exist;
        %abort cancel;
     %end ;
  %end ;
%mend ms_lib;